=====
bisos
=====

.. contents::
   :depth: 3
..

BISOS (Unix Internet Services OS) Namespace: A name base for a
collection of libraries and command modules.

Support
=======

| For support, ideas, suggestions, criticism, comments and questions;
  please contact the author/maintainer
| `Mohsen Banan <http://mohsen.1.banan.byname.net>`__ at:
  http://mohsen.1.banan.byname.net/contact

Documentation
=============

Part of ByStar Digital Ecosystem http://www.by-star.net.

This module’s primary documentation is in
http://www.by-star.net/PLPC/180047

Installation
============

::

    pip install unisos

See Also
========

unisos.ucf unisos.icm unisos.common
